==> iaxmodem_1.1.1~dfsg.orig.tar.gz: iaxmodem-1.1.1/lib/spandsp/src/v27ter_rx_4800_fixed_rrc.h <==
#define PULSESHAPER_4800_GAIN        32767.000000f
#define PULSESHAPER_4800_COEFF_SETS  8
static const complexi16_t pulseshaper_4800[PULSESHAPER_4800_COEFF_SETS][27] =
{
    {
        {       0,        0},     /* Filter 0 */
        {      30,      -93},
        {     -52,       -8},
        {       0,     -233},
        {     261,      -41},
        {       2,        8},
        {     439,     -224},
        {     568,      782},
        {    -696,      696},
        {    -143,     -104},
        {    -695,     1365},
        {   -3619,    -1176},
        {     934,    -5900},
        {    7298,        0},
        {    1141,     7208},
        {   -5681,     1846},
        {   -1727,    -3391},
        {    1239,     -900},
        {    -125,     -125},
        {     578,     -796},
        {     861,      439},
        {    -152,      469},
        {       8,        1},
        {       0,      264},
        {    -230,       36},
        {     -16,      -50},
        {     -87,       44}
    },
    {
        {       0,        0},     /* Filter 1 */
        {      26,      -81},
        {     -76,      -12},
        {       0,     -249},
        {     246,      -39},
        {     -13,      -41},
        {     500,     -255},
        {     589,      811},
        {    -660,      660},
        {      -8,       -5},
        {    -815,     1600},
        {   -3898,    -1266},
        {     969,    -6123},
        {    7375,        0},
        {    1126,     7110},
        {   -5454,     1772},
        {   -1594,    -3129},
        {    1032,     -750},
        {    -233,     -233},
        {     600,     -826},
        {     822,      419},
        {    -131,      403},
        {      56,        9},
        {       0,      274},
        {    -212,       33},
        {      -9,      -27},
        {     -97,       49}
    },
    {
        {       0,        0},     /* Filter 2 */
        {      21,      -67},
        {    -100,      -15},
        {       0,     -262},
        {     227,      -35},
        {     -30,      -95},
        {     561,     -286},
        {     606,      834},
        {    -614,      614},
        {     138,      100},
        {    -939,     1844},
        {   -4173,    -1356},
        {    1002,    -6331},
        {    7431,        0},
        {    1107,     6992},
        {   -5216,     1694},
        {   -1460,    -2866},
        {     834,     -606},
        {    -330,     -330},
        {     615,     -846},
        {     778,      396},
        {    -110,      338},
        {     100,       15},
        {       0,      280},
        {    -192,       30},
        {      -2,       -6},
        {    -104,       53}
    },
    {
        {       0,        0},     /* Filter 3 */
        {      16,      -51},
        {    -124,      -19},
        {       0,     -272},
        {     202,      -32},
        {     -49,     -152},
        {     620,     -315},
        {     617,      850},
        {    -559,      559},
        {     296,      215},
        {   -1066,     2093},
        {   -4444,    -1444},
        {    1033,    -6522},
        {    7465,        0},
        {    1085,     6854},
        {   -4967,     1613},
        {   -1327,    -2606},
        {     645,     -468},
        {    -417,     -417},
        {     622,     -856},
        {     729,      371},
        {     -89,      274},
        {     139,       22},
        {       0,      281},
        {    -171,       27},
        {       4,       14},
        {    -110,       56}
    },
    {
        {       0,        0},     /* Filter 4 */
        {      10,      -33},
        {    -148,      -23},
        {       0,     -279},
        {     173,      -27},
        {     -68,     -212},
        {     676,     -344},
        {     623,      857},
        {    -493,      493},
        {     466,      338},
        {   -1196,     2347},
        {   -4709,    -1530},
        {    1060,    -6697},
        {    7476,        0},
        {    1060,     6697},
        {   -4709,     1530},
        {   -1196,    -2347},
        {     466,     -338},
        {    -493,     -493},
        {     623,     -857},
        {     676,      344},
        {     -68,      212},
        {     173,       27},
        {       0,      279},
        {    -148,       23},
        {      10,       33},
        {    -113,       58}
    },
    {
        {       0,        0},     /* Filter 5 */
        {       4,      -14},
        {    -171,      -27},
        {       0,     -281},
        {     139,      -22},
        {     -89,     -274},
        {     729,     -371},
        {     622,      856},
        {    -417,      417},
        {     645,      468},
        {   -1327,     2606},
        {   -4967,    -1613},
        {    1085,    -6854},
        {    7465,        0},
        {    1033,     6522},
        {   -4444,     1444},
        {   -1066,    -2093},
        {     296,     -215},
        {    -559,     -559},
        {     617,     -850},
        {     620,      315},
        {     -49,      152},
        {     202,       32},
        {       0,      272},
        {    -124,       19},
        {      16,       51},
        {    -115,       58}
    },
    {
        {       0,        0},     /* Filter 6 */
        {      -2,        6},
        {    -192,      -30},
        {       0,     -280},
        {     100,      -15},
        {    -110,     -338},
        {     778,     -396},
        {     615,      846},
        {    -330,      330},
        {     834,      606},
        {   -1460,     2866},
        {   -5216,    -1694},
        {    1107,    -6992},
        {    7431,        0},
        {    1002,     6331},
        {   -4173,     1356},
        {    -939,    -1844},
        {     138,     -100},
        {    -614,     -614},
        {     606,     -834},
        {     561,      286},
        {     -30,       95},
        {     227,       35},
        {       0,      262},
        {    -100,       15},
        {      21,       67},
        {    -115,       58}
    },
    {
        {       0,        0},     /* Filter 7 */
        {      -9,       27},
        {    -212,      -33},
        {       0,     -274},
        {      56,       -9},
        {    -131,     -403},
        {     822,     -419},
        {     600,      826},
        {    -233,      233},
        {    1032,      750},
        {   -1594,     3129},
        {   -5454,    -1772},
        {    1126,    -7110},
        {    7375,        0},
        {     969,     6123},
        {   -3898,     1266},
        {    -815,    -1600},
        {      -8,        5},
        {    -660,     -660},
        {     589,     -811},
        {     500,      255},
        {     -13,       41},
        {     246,       39},
        {       0,      249},
        {     -76,       12},
        {      26,       81},
        {    -112,       57}
    }
};

==> iaxmodem_1.2.0~dfsg.orig.tar.gz: iaxmodem-1.2.0/lib/spandsp/src/v27ter_rx_4800_fixed_rrc.h <==
#define RX_PULSESHAPER_4800_GAIN        32767.000000f
#define RX_PULSESHAPER_4800_COEFF_SETS  8
static const complexi16_t rx_pulseshaper_4800[RX_PULSESHAPER_4800_COEFF_SETS][27] =
{
    {
        {       0,        0},     /* Filter 0 */
        {      30,      -93},
        {     -52,       -8},
        {       0,     -233},
        {     261,      -41},
        {       2,        8},
        {     439,     -224},
        {     568,      782},
        {    -696,      696},
        {    -143,     -104},
        {    -695,     1365},
        {   -3619,    -1176},
        {     934,    -5900},
        {    7298,        0},
        {    1141,     7208},
        {   -5681,     1846},
        {   -1727,    -3391},
        {    1239,     -900},
        {    -125,     -125},
        {     578,     -796},
        {     861,      439},
        {    -152,      469},
        {       8,        1},
        {       0,      264},
        {    -230,       36},
        {     -16,      -50},
        {     -87,       44}
    },
    {
        {       0,        0},     /* Filter 1 */
        {      26,      -81},
        {     -76,      -12},
        {       0,     -249},
        {     246,      -39},
        {     -13,      -41},
        {     500,     -255},
        {     589,      811},
        {    -660,      660},
        {      -8,       -5},
        {    -815,     1600},
        {   -3898,    -1266},
        {     969,    -6123},
        {    7375,        0},
        {    1126,     7110},
        {   -5454,     1772},
        {   -1594,    -3129},
        {    1032,     -750},
        {    -233,     -233},
        {     600,     -826},
        {     822,      419},
        {    -131,      403},
        {      56,        9},
        {       0,      274},
        {    -212,       33},
        {      -9,      -27},
        {     -97,       49}
    },
    {
        {       0,        0},     /* Filter 2 */
        {      21,      -67},
        {    -100,      -15},
        {       0,     -262},
        {     227,      -35},
        {     -30,      -95},
        {     561,     -286},
        {     606,      834},
        {    -614,      614},
        {     138,      100},
        {    -939,     1844},
        {   -4173,    -1356},
        {    1002,    -6331},
        {    7431,        0},
        {    1107,     6992},
        {   -5216,     1694},
        {   -1460,    -2866},
        {     834,     -606},
        {    -330,     -330},
        {     615,     -846},
        {     778,      396},
        {    -110,      338},
        {     100,       15},
        {       0,      280},
        {    -192,       30},
        {      -2,       -6},
        {    -104,       53}
    },
    {
        {       0,        0},     /* Filter 3 */
        {      16,      -51},
        {    -124,      -19},
        {       0,     -272},
        {     202,      -32},
        {     -49,     -152},
        {     620,     -315},
        {     617,      850},
        {    -559,      559},
        {     296,      215},
        {   -1066,     2093},
        {   -4444,    -1444},
        {    1033,    -6522},
        {    7465,        0},
        {    1085,     6854},
        {   -4967,     1613},
        {   -1327,    -2606},
        {     645,     -468},
        {    -417,     -417},
        {     622,     -856},
        {     729,      371},
        {     -89,      274},
        {     139,       22},
        {       0,      281},
        {    -171,       27},
        {       4,       14},
        {    -110,       56}
    },
    {
        {       0,        0},     /* Filter 4 */
        {      10,      -33},
        {    -148,      -23},
        {       0,     -279},
        {     173,      -27},
        {     -68,     -212},
        {     676,     -344},
        {     623,      857},
        {    -493,      493},
        {     466,      338},
        {   -1196,     2347},
        {   -4709,    -1530},
        {    1060,    -6697},
        {    7476,        0},
        {    1060,     6697},
        {   -4709,     1530},
        {   -1196,    -2347},
        {     466,     -338},
        {    -493,     -493},
        {     623,     -857},
        {     676,      344},
        {     -68,      212},
        {     173,       27},
        {       0,      279},
        {    -148,       23},
        {      10,       33},
        {    -113,       58}
    },
    {
        {       0,        0},     /* Filter 5 */
        {       4,      -14},
        {    -171,      -27},
        {       0,     -281},
        {     139,      -22},
        {     -89,     -274},
        {     729,     -371},
        {     622,      856},
        {    -417,      417},
        {     645,      468},
        {   -1327,     2606},
        {   -4967,    -1613},
        {    1085,    -6854},
        {    7465,        0},
        {    1033,     6522},
        {   -4444,     1444},
        {   -1066,    -2093},
        {     296,     -215},
        {    -559,     -559},
        {     617,     -850},
        {     620,      315},
        {     -49,      152},
        {     202,       32},
        {       0,      272},
        {    -124,       19},
        {      16,       51},
        {    -115,       58}
    },
    {
        {       0,        0},     /* Filter 6 */
        {      -2,        6},
        {    -192,      -30},
        {       0,     -280},
        {     100,      -15},
        {    -110,     -338},
        {     778,     -396},
        {     615,      846},
        {    -330,      330},
        {     834,      606},
        {   -1460,     2866},
        {   -5216,    -1694},
        {    1107,    -6992},
        {    7431,        0},
        {    1002,     6331},
        {   -4173,     1356},
        {    -939,    -1844},
        {     138,     -100},
        {    -614,     -614},
        {     606,     -834},
        {     561,      286},
        {     -30,       95},
        {     227,       35},
        {       0,      262},
        {    -100,       15},
        {      21,       67},
        {    -115,       58}
    },
    {
        {       0,        0},     /* Filter 7 */
        {      -9,       27},
        {    -212,      -33},
        {       0,     -274},
        {      56,       -9},
        {    -131,     -403},
        {     822,     -419},
        {     600,      826},
        {    -233,      233},
        {    1032,      750},
        {   -1594,     3129},
        {   -5454,    -1772},
        {    1126,    -7110},
        {    7375,        0},
        {     969,     6123},
        {   -3898,     1266},
        {    -815,    -1600},
        {      -8,        5},
        {    -660,     -660},
        {     589,     -811},
        {     500,      255},
        {     -13,       41},
        {     246,       39},
        {       0,      249},
        {     -76,       12},
        {      26,       81},
        {    -112,       57}
    }
};
